@@ -44,17 +44,15 @@ function(behavior,phaseX,v1,ABxlab,ABylab, ABmain){
     j=j+1
   }
   
-  graphics.off()
-  layout(rbind(1,2), heights=c(6,1))
+  
+  layout(rbind(1,2), heights=c(4,1))
   plot(x,y,type="o",ylim=c(min,max),col="red",xlab=ABxlab,ylab=ABylab,main=ABmain,bty="l")
-  #
+  
   abline(h=meanA,col="green",lwd=3)
   abline(h=SDabove,col="black",lwd=3)
   abline(h=SDbelow,col="black",lwd=3)
   
-  #par(mar=c(1, 1, 1, 1))
-  #plot.new()
-  #legend("center", c("behavior","+1sd","mean","-1sd"), col = c("red","black", "green","black"), lwd = 1,ncol=4,bty ="n")
+  
   sdp<-c("SD",round(sdA,2))
   psdu<-c("+1SD",round(SDabove,2))
   pmean<-c("mean",round(meanA,2))
@@ -63,6 +61,5 @@ function(behavior,phaseX,v1,ABxlab,ABylab, ABmain){
   
   tprint=c(sdp,psdu,pmean,psdb)
   print(tprint)
-  ab<-NULL
-  ab<<-recordPlot()
+  
 }
